@@ -3,13 +3,13 @@ import logging
 from exceptions import JournalException
 from models import (Journal, Tag, Template)
 
-from django.db import models
+import django.db.models
 from django.conf import settings
 
 from decorator import commit_on_success
 
 __all__ = ('record', 'error_record', 'Journal')
-__version__ = '1.12.0'
+__version__ = '1.16.0'
 
 def unicode_truncate(s, length, encoding='utf-8'):
     '''Truncate an unicode string so that its UTF-8 encoding is less than
@@ -54,7 +54,7 @@ def record(tag, template, using=None, **kwargs):
         if value is None:
             continue
         tag = Tag.objects.using(using).get_cached(name=tag)
-        if isinstance(value, models.Model):
+        if isinstance(value, django.db.models.Model):
             journal.objectdata_set.create(tag=tag, content_object=value)
         else:
             journal.stringdata_set.create(tag=tag, content=unicode(value))
